from django.shortcuts import *
from django.contrib.auth.decorators import login_required
from django.template.context import Context, RequestContext
from django.template import Template,loader
from django.http import HttpResponse,  HttpResponseRedirect
from comun.utilidades import dictfetchall

from complementariedad.forms import *

def reporte_n_principales_productos(pais, flujo_comercial, n = 5):
    query = """
            SELECT cc.pais_id, cp.iso3166_3, cc.codigo_armonizado_id, cca.codigo,
                   SUM(cantidad) AS cantidad, cum.simbolo,
                   SUM(cc.monto) AS monto
            FROM comun_comercio AS cc
            INNER JOIN comun_pais AS cp ON cp.id = cc.pais_id
            INNER JOIN comun_codigoarmonizado AS cca
                ON cca.id = cc.codigo_armonizado_id
            INNER JOIN comun_unidadmedida AS cum ON cum.id = cc.unidad_medida_id
            WHERE cc.pais_id <> %s
            AND cc.flujo_comercial = %s
            AND cc.id in
                (SELECT id
                 FROM comun_comercio
                 WHERE (pais_id, codigo_armonizado_id) in
                     (SELECT pais_id, codigo_armonizado_id
                      FROM comun_comercio
                      WHERE pais_relacion_id in
                         (SELECT id
                          FROM comun_pais
                          WHERE anyo_inclusion is NULL)
                      AND flujo_comercial = 1
                      EXCEPT
                      SELECT pais_id, codigo_armonizado_id
                      FROM comun_comercio
                      WHERE pais_relacion_id = %s AND flujo_comercial = %s
                     )
                )
            AND cc.pais_relacion_id in
                (SELECT id FROM comun_pais WHERE anyo_inclusion is NULL)
            GROUP BY cc.pais_id, cp.iso3166_3, cc.codigo_armonizado_id,
                     cca.codigo, cum.simbolo
            ORDER BY cantidad DESC
            LIMIT 5
            """

    try:
        cursor = connection.cursor()

        cursor.execute(query, [pais, flujo_comercial, pais, flujo_comercial])

        filas = dictfetchall(cursor)

    except Exception as e:
        logger.fatal('Exception ejecutando consulta de reporte general: %s' % e)
        print e
        raise e

    return filas

def reporte_por_paises_y_productos(pais, flujo_comercial,
                                   paises_relacion, productos):
    query = """
            SELECT cc.pais_id, cp.iso3166_3, cca.codigo, cc.cantidad,
                   cum.simbolo, cc.monto
            FROM comun_comercio AS cc
            INNER JOIN comun_codigoarmonizado AS cca
                ON cc.codigo_armonizado_id = cca.id
            INNER JOIN comun_pais AS cp ON cp.id = cc.pais_id
            INNER JOIN comun_unidadmedida AS cum ON cc.unidad_medida_id = cum.id
            WHERE cc.pais_id in %s
            AND cc.flujo_comercial = %s
            AND (cc.codigo_armonizado_id in %s
            OR cc.codigo_armonizado_id in (SELECT hs_96_id 
                                           FROM comun_codigoarmonizado AS cca
                                           INNER JOIN comun_conversionhs AS cchs 
                                               ON cchs.hs_02_id = cca.id
                                           WHERE cca.id in %s))
            AND cc.id in
               (SELECT id FROM comun_comercio
                WHERE (pais_id, codigo_armonizado_id) in
                   (SELECT pais_id, codigo_armonizado_id
                    FROM comun_comercio
                    WHERE pais_relacion_id in
                        (SELECT id FROM comun_pais WHERE anyo_inclusion is NULL)
                    AND flujo_comercial = %s
                EXCEPT
                    SELECT pais_id, codigo_armonizado_id
                    FROM comun_comercio
                    WHERE pais_relacion_id = %s AND flujo_comercial = %s
               )
           )
            AND cc.pais_relacion_id in (SELECT id FROM comun_pais
                                        WHERE anyo_inclusion is NULL)
            """

    try:
        cursor = connection.cursor()

        cursor.execute(query, [paises_relacion, flujo_comercial, productos,
                               productos, flujo_comercial, pais,
                               flujo_comercial])

        filas = dictfetchall(cursor)

    except Exception as e:
        logger.fatal('Exception ejecutando consulta de reporte general: %s' % e)
        print e
        raise e

    return filas

def reporte_productos_por_pais_relacion(pais, flujo_comercial, pais_relacion):
    query = """
            SELECT cc.codigo_armonizado_id, cca.codigo,
            SUM(cc.cantidad) AS cantidad, cum.simbolo, SUM(cc.monto) AS monto
            FROM comun_comercio AS cc
            INNER JOIN comun_codigoarmonizado AS cca
            ON cca.id = cc.codigo_armonizado_id
            INNER JOIN comun_unidadmedida AS cum ON cum.id = cc.unidad_medida_id
            WHERE cc.pais_id = 2
            AND cc.flujo_comercial = 1
            AND cc.pais_relacion_id in (SELECT id FROM comun_pais
                                        WHERE anyo_inclusion is NULL)
            AND cc.id in (SELECT id FROM comun_comercio
                          WHERE (pais_id, codigo_armonizado_id) in
                             (SELECT pais_id, codigo_armonizado_id
                              FROM comun_comercio
                              WHERE pais_relacion_id in
                                 (SELECT id FROM comun_pais
                                  WHERE anyo_inclusion is NULL)
                              AND flujo_comercial = 1
                              EXCEPT
                              SELECT pais_id, codigo_armonizado_id
                              FROM comun_comercio
                              WHERE pais_relacion_id = 1 AND flujo_comercial = 1
                              )
                          )
            GROUP BY cc.codigo_armonizado_id, cca.codigo, cum.simbolo
            ORDER BY cc.codigo_armonizado_id
            """
    try:
        cursor = connection.cursor()

        cursor.execute(query, [])

        filas = dictfetchall(cursor)

    except Exception as e:
        logger.fatal('Exception ejecutando consulta de reporte general: %s' % e)
        print e
        raise e

    return filas


def reporte_general(pais, flujo_comercial):
    query = """
            SELECT cc.pais_id, cp.iso3166_3, SUM(cc.monto) AS monto
            FROM comun_comercio AS cc
            INNER JOIN comun_pais AS cp ON cp.id = cc.pais_id
            WHERE cc.pais_id <> %s
                AND cc.flujo_comercial = %s
                AND cc.id in
                    (SELECT id
                     FROM comun_comercio
                     WHERE (pais_id, codigo_armonizado_id) in
                        (SELECT pais_id, codigo_armonizado_id
                         FROM comun_comercio
                         WHERE pais_relacion_id in
                            (SELECT id
                             FROM comun_pais
                             WHERE anyo_inclusion is NULL
                                 AND flujo_comercial = %s)
                         EXCEPT
                         SELECT pais_id, codigo_armonizado_id
                         FROM comun_comercio
                         WHERE pais_relacion_id = %s AND flujo_comercial = %s
                        )
                    )
                AND cc.pais_relacion_id in
                    (SELECT id FROM comun_pais WHERE anyo_inclusion is NULL)
            GROUP BY cc.pais_id, cp.iso3166_3
            ORDER BY cc.pais_id
            """
    try:
        cursor = connection.cursor()

        cursor.execute(query, [pais, flujo_comercial, flujo_comercial, pais,
                               flujo_comercial])

        filas = dictfetchall(cursor)

        for fila in filas:
            sum_monto = 0.0

            fila['monto'] = fila['monto'] / 100000

            sum_monto = sum_monto + fila['monto']

        for fila in filas:
            fila['porcentaje'] = 100 * fila['monto'] / sum_monto

    except Exception as e:
        logger.fatal('Exception ejecutando consulta de reporte general: %s' % e)
        print e
        raise e

    return filas

@login_required
def complementariedad(request):
    if request.method == 'POST':
        formu = FormularioComplementariedad(request.POST)
        if formu.is_valid():
            pais = formu.cleaned_data['pais']
        
            flujo_comercial = formu.cleaned_data['flujo_comercial']

            codigos_armonizados = formu.cleaned_data['codigo_armonizado']
        
            paises_relacion = formu.cleaned_data['paises_relacion']
        
            return render_to_response('complementariedad/resultado.html',context_instance = RequestContext(request))
    else:
        formu = FormularioComplementariedad()

    return render_to_response('complementariedad/complementariedad.html',{'FormularioComplementariedad':formu}, context_instance = RequestContext(request))
